@@ -322,7 +322,6 @@ class LCDataTablesListBase(
         return False
 
     def show_record_activity_stream_deletes_btn(self) -> bool:
-
         if not self.concord_event_tracked_model():
             return False
 
@@ -633,18 +632,10 @@ class LCDeleteViewBase(
         return []
 
     def get_context_data(self, **kwargs: Any) -> dict:
-        context = super().get_context_data()
-
-        if self.request.method == 'GET':
-            warnings = self.get_special_warnings()
-        else:
-            warnings = []
-
-        context.update({
-            'special_warnings': warnings,
-        })
-
-        return context
+        return super().get_context_data(
+            special_warnings=self.get_special_warnings() if self.request.method == 'GET' else [],
+            **kwargs,
+        )
 
     def get_success_url(self) -> str:
         if self.action != 'delete':
